Index: src/compiler/ppc/instruction-selector-ppc.cc |
diff --git a/src/compiler/ppc/instruction-selector-ppc.cc b/src/compiler/ppc/instruction-selector-ppc.cc |
index 93ad4575564cf24cf3e202245726836c40d15425..f6ebbdf5d6ab249a47cc1cc5469b0a139643f8b5 100644 |
--- a/src/compiler/ppc/instruction-selector-ppc.cc |
+++ b/src/compiler/ppc/instruction-selector-ppc.cc |
@@ -1431,12 +1431,12 @@ void VisitWordCompareZero(InstructionSelector* selector, Node* user, |
if (ProjectionIndexOf(value->op()) == 1u) { |
// We cannot combine the <Operation>WithOverflow with this branch |
// unless the 0th projection (the use of the actual value of the |
// <Operation> is either NULL, which means there's no use of the |
// actual value, or was already defined, which means it is scheduled |
// *AFTER* this branch). |
Node* const node = value->InputAt(0); |
Node* const result = NodeProperties::FindProjection(node, 0); |
- if (result == NULL || selector->IsDefined(result)) { |
+ if (result == nullptr || selector->IsDefined(result)) { |
switch (node->opcode()) { |
case IrOpcode::kInt32AddWithOverflow: |
cont->OverwriteAndNegateIfEqual(kOverflow); |
@@ -1431,12 +1431,12 @@ void VisitWordCompareZero(InstructionSelector* selector, Node* user, |
// We cannot combine the <Operation>WithOverflow with this branch |
// unless the 0th projection (the use of the actual value of the |
- // <Operation> is either NULL, which means there's no use of the |
+ // <Operation> is either nullptr, which means there's no use of the |
// actual value, or was already defined, which means it is scheduled |
// *AFTER* this branch). |